<?php

namespace Nextend\SmartSlider3\Form\Element\Radio;

use Nextend\Framework\Form\Element\Radio\AbstractRadioIcon;

class VerticalAlign extends AbstractRadioIcon {

    protected $options = array(
        'top'    => 'ssi_16 ssi_16--verticaltop',
        'middle' => 'ssi_16 ssi_16--verticalcenter',
        'bottom' => 'ssi_16 ssi_16--verticalbottom'
    );
}